@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -83,7 +83,7 @@ get_filename_from_uri (const char *uri)
 }
 
 /* Some docs report titles with confusing extensions (ex. .doc for pdf).
-   Let's show the filename in this case */
+	   Erase the confusing extension of the title */
 static void
 ev_window_title_sanitize_title (EvWindowTitle *window_title, char **title) {
 	const gchar *backend;
@@ -97,7 +97,7 @@ ev_window_title_sanitize_title (EvWindowTitle *window_title, char **title) {
 			char *new_title;
 			char *filename = get_filename_from_uri (window_title->uri);
 
-			new_title = g_strdup_printf ("%s (%s)", *title, filename);
+			new_title = g_strndup (*title, strlen(*title) - strlen(bad_extensions[i].text));
 			g_free (*title);
 			*title = new_title;
 
@@ -142,7 +142,15 @@ ev_window_title_update (EvWindowTitle *window_title)
 	}
 
 	if (title && window_title->uri) {
+		char *tmp_title;
+		char *filename = get_filename_from_uri (window_title->uri);
+
 		ev_window_title_sanitize_title (window_title, &title);
+		tmp_title = g_strdup_printf ("%s — %s", filename, title);
+                g_free (title);
+                g_free (filename);
+
+                title = tmp_title;
 	} else if (window_title->uri) {
 		title = get_filename_from_uri (window_title->uri);
 	} else if (!title) {
@@ -159,7 +167,7 @@ ev_window_title_update (EvWindowTitle *window_title)
 		gtk_window_set_title (window, title);
 		break;
 	case EV_WINDOW_TITLE_PASSWORD:
-		password_title = g_strdup_printf (_("%s - Password Required"), title);
+		password_title = g_strdup_printf (_("%s — Password Required"), title);
 		gtk_window_set_title (window, password_title);
 		g_free (password_title);
 		break;
